@@ -47,7 +47,7 @@ def test_v1alpha1(export_schema):
 
 def test_v1alpha1_example(snapshot_json):
     schema = v1alpha1.Schema(
-        provider=v1alpha1.Provider(
+        id=v1alpha1.ID(
             schema_version="v1",
             name="example",
             publisher="common-fate",
@@ -84,3 +84,11 @@ def test_v1alpha1_example_no_provider(snapshot_json):
     )
 
     assert schema.dict() == snapshot_json
+
+
+def test_v1alpha1_minimal(snapshot_json):
+    schema = v1alpha1.Schema(
+        meta=v1alpha1.Meta(framework="dev"),
+    )
+
+    assert schema.dict(exclude_none=True) == snapshot_json
